==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/JOBSCHEDULEPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour JOBSCHEDULEPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="JOBSCHEDULEPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCJCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "JOBSCHEDULEPARAMETERID_Type", propOrder = {
    "scjcode",
    "line"
})
public class JOBSCHEDULEPARAMETERID_Type {

    @XmlElement(name = "SCJCODE", required = true)
    protected String scjcode;
    @XmlElement(name = "LINE")
    protected Long line;

    /**
     * Obtient la valeur de la propriété scjcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCJCODE() {
        return scjcode;
    }

    /**
     * Définit la valeur de la propriété scjcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCJCODE(String value) {
        this.scjcode = value;
    }

    /**
     * Obtient la valeur de la propriété line.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getLINE() {
        return line;
    }

    /**
     * Définit la valeur de la propriété line.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setLINE(Long value) {
        this.line = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/JOBSCHEDULEPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for JOBSCHEDULEPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="JOBSCHEDULEPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCJCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "JOBSCHEDULEPARAMETERID_Type", propOrder = {
    "scjcode",
    "line"
})
public class JOBSCHEDULEPARAMETERID_Type {

    @XmlElement(name = "SCJCODE", required = true)
    protected String scjcode;
    @XmlElement(name = "LINE")
    protected Long line;

    /**
     * Gets the value of the scjcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCJCODE() {
        return scjcode;
    }

    /**
     * Sets the value of the scjcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCJCODE(String value) {
        this.scjcode = value;
    }

    /**
     * Gets the value of the line property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getLINE() {
        return line;
    }

    /**
     * Sets the value of the line property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setLINE(Long value) {
        this.line = value;
    }

}
